@@ -1,7 +1,7 @@
 import argparse
 
 import apache_beam as beam
-from apache_beam.io import ReadFromText
+from apache_beam.io import ReadFromText, Read
 from apache_beam.io import WriteToAvro
 from apache_beam.options.pipeline_options import PipelineOptions
 
@@ -10,7 +10,7 @@ import json
 import logging
 from org.codeforrussia.selector.standardizer.standardizer_registry_factory import SupportedInputFormat, StandardizerRegistryFactory
 from org.codeforrussia.selector.standardizer.schemas.schema_registry_factory import StandardProtocolSchemaRegistryFactory
-from datetime import date
+
 
 def add_gcp_connection(known_args):
     if known_args.google_application_credentials is not None:
@@ -38,13 +38,6 @@ def run(argv=None):
                         required=True,
                         help='Output file to write results to')
 
-    parser.add_argument('--multi-input',
-                        type=bool,
-                        dest='multi_input',
-                        required=False,
-                        default=False,
-                        help='True if multiple inputs. The corresponding file pattern will be appended.')
-
     parser.add_argument('--google-application-credentials',
                         type=str,
                         dest='google_application_credentials',
@@ -64,8 +57,7 @@ def run(argv=None):
     pipeline_options = PipelineOptions(pipeline_args)
 
     with beam.Pipeline(options=pipeline_options) as p:
-        filepattern_suffix = "/*" if known_args.multi_input else ""
-        lines = p | 'ReadFromText' >> ReadFromText(known_args.input + filepattern_suffix)
+        lines = p | 'ReadFromText' >> ReadFromText(known_args.input)
 
         jsonsGroupedBySchema = (lines
                                 | 'JSONLoads' >> beam.Map(json.loads)
@@ -74,8 +66,7 @@ def run(argv=None):
 
         for schema_key, jsons in zip(registered_schema_keys, jsonsGroupedBySchema):
             schema = schema_registry.search_schema(*schema_key)
-            today = date.today()
-            output_path = (Path(known_args.output) / today.strftime("%d-%m-%Y") / schema["name"].replace(".", "_")).as_posix()
+            output_path = (Path(known_args.output) / schema["name"].replace(".", "_")).as_posix()
             (jsons
              | 'Map' >> beam.Map(lambda data: data["sdata"])
              | 'WriteToAvro' >> WriteToAvro(output_path, schema=schema, file_name_suffix=".avro"))
